package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcBrand;

/**
 * cmc品牌项目支付审批Mapper接口
 * 
 * @author cmc
 * @date 2024-04-29
 */
public interface CmcBrandMapper 
{
    /**
     * 查询cmc品牌项目支付审批
     * 
     * @param brandId cmc品牌项目支付审批主键
     * @return cmc品牌项目支付审批
     */
    public CmcBrand selectCmcBrandByBrandId(String brandId);

    /**
     * 查询cmc品牌项目支付审批列表
     * 
     * @param cmcBrand cmc品牌项目支付审批
     * @return cmc品牌项目支付审批集合
     */
    public List<CmcBrand> selectCmcBrandList(CmcBrand cmcBrand);

    /**
     * 新增cmc品牌项目支付审批
     * 
     * @param cmcBrand cmc品牌项目支付审批
     * @return 结果
     */
    public int insertCmcBrand(CmcBrand cmcBrand);

    /**
     * 修改cmc品牌项目支付审批
     * 
     * @param cmcBrand cmc品牌项目支付审批
     * @return 结果
     */
    public int updateCmcBrand(CmcBrand cmcBrand);

    /**
     * 删除cmc品牌项目支付审批
     * 
     * @param brandId cmc品牌项目支付审批主键
     * @return 结果
     */
    public int deleteCmcBrandByBrandId(String brandId);

    /**
     * 批量删除cmc品牌项目支付审批
     * 
     * @param brandIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcBrandByBrandIds(String[] brandIds);
}
