package com.ruoyi.web.controller.oa;

import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcBrand;
import com.ruoyi.oa.service.ICmcBrandService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc品牌项目支付审批Controller
 * 
 * @author cmc
 * @date 2024-04-29
 */
@RestController
@RequestMapping("/oa/brand")
public class CmcBrandController extends BaseController
{
    @Autowired
    private ICmcBrandService cmcBrandService;

    /**
     * 查询cmc品牌项目支付审批列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcBrand cmcBrand)
    {
        startPage();
        List<CmcBrand> list = cmcBrandService.selectCmcBrandList(cmcBrand);
        return getDataTable(list);
    }

    /**
     * 导出cmc品牌项目支付审批列表
     */
    @Log(title = "cmc品牌项目支付审批", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcBrand cmcBrand)
    {
        List<CmcBrand> list = cmcBrandService.selectCmcBrandList(cmcBrand);
        ExcelUtil<CmcBrand> util = new ExcelUtil<CmcBrand>(CmcBrand.class);
        util.exportExcel(response, list, "cmc品牌项目支付审批数据");
    }

    /**
     * 获取cmc品牌项目支付审批详细信息
     */
    @GetMapping(value = "/{brandId}")
    public AjaxResult getInfo(@PathVariable("brandId") String brandId)
    {
        return success(cmcBrandService.selectCmcBrandByBrandId(brandId));
    }

    /**
     * 新增cmc品牌项目支付审批
     */
    @Log(title = "cmc品牌项目支付审批", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcBrand cmcBrand)
    {
        return toAjax(cmcBrandService.insertCmcBrand(cmcBrand));
    }

    /**
     * 修改cmc品牌项目支付审批
     */
    @Log(title = "cmc品牌项目支付审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcBrand cmcBrand)
    {
        cmcBrand.setCwUserId(getLoginUser().getUserId());
        cmcBrand.setCwTime(new Date());
        return toAjax(cmcBrandService.updateCmcBrand(cmcBrand));
    }

    /**
     * 删除cmc品牌项目支付审批
     */
    @Log(title = "cmc品牌项目支付审批", businessType = BusinessType.DELETE)
	@DeleteMapping("/{brandIds}")
    public AjaxResult remove(@PathVariable String[] brandIds)
    {
        return success(cmcBrandService.deleteCmcBrandByBrandIds(brandIds));
    }
}
